==> aws-java-sdk-logs-1.10.65-sources.jar: com/amazonaws/services/logs/model/transform/RejectedLogEventsInfoJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.logs.model.transform;

import static com.amazonaws.util.StringUtils.UTF8;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.OutputStreamWriter;
import java.io.StringWriter;
import java.io.Writer;
import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.logs.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * RejectedLogEventsInfoMarshaller
 */
public class RejectedLogEventsInfoJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(RejectedLogEventsInfo rejectedLogEventsInfo,
            SdkJsonGenerator jsonGenerator) {
        if (rejectedLogEventsInfo == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (rejectedLogEventsInfo.getTooNewLogEventStartIndex() != null) {
                jsonGenerator.writeFieldName("tooNewLogEventStartIndex")
                        .writeValue(
                                rejectedLogEventsInfo
                                        .getTooNewLogEventStartIndex());
            }
            if (rejectedLogEventsInfo.getTooOldLogEventEndIndex() != null) {
                jsonGenerator.writeFieldName("tooOldLogEventEndIndex")
                        .writeValue(
                                rejectedLogEventsInfo
                                        .getTooOldLogEventEndIndex());
            }
            if (rejectedLogEventsInfo.getExpiredLogEventEndIndex() != null) {
                jsonGenerator.writeFieldName("expiredLogEventEndIndex")
                        .writeValue(
                                rejectedLogEventsInfo
                                        .getExpiredLogEventEndIndex());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static RejectedLogEventsInfoJsonMarshaller instance;

    public static RejectedLogEventsInfoJsonMarshaller getInstance() {
        if (instance == null)
            instance = new RejectedLogEventsInfoJsonMarshaller();
        return instance;
    }

}

==> aws-java-sdk-logs-1.10.76-sources.jar: com/amazonaws/services/logs/model/transform/RejectedLogEventsInfoJsonMarshaller.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.logs.model.transform;

import java.util.Map;
import java.util.List;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.logs.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.BinaryUtils;
import com.amazonaws.util.StringUtils;
import com.amazonaws.util.IdempotentUtils;
import com.amazonaws.util.StringInputStream;
import com.amazonaws.util.json.*;

/**
 * RejectedLogEventsInfoMarshaller
 */
public class RejectedLogEventsInfoJsonMarshaller {

    /**
     * Marshall the given parameter object, and output to a SdkJsonGenerator
     */
    public void marshall(RejectedLogEventsInfo rejectedLogEventsInfo,
            StructuredJsonGenerator jsonGenerator) {

        if (rejectedLogEventsInfo == null) {
            throw new AmazonClientException(
                    "Invalid argument passed to marshall(...)");
        }

        try {
            jsonGenerator.writeStartObject();

            if (rejectedLogEventsInfo.getTooNewLogEventStartIndex() != null) {
                jsonGenerator.writeFieldName("tooNewLogEventStartIndex")
                        .writeValue(
                                rejectedLogEventsInfo
                                        .getTooNewLogEventStartIndex());
            }
            if (rejectedLogEventsInfo.getTooOldLogEventEndIndex() != null) {
                jsonGenerator.writeFieldName("tooOldLogEventEndIndex")
                        .writeValue(
                                rejectedLogEventsInfo
                                        .getTooOldLogEventEndIndex());
            }
            if (rejectedLogEventsInfo.getExpiredLogEventEndIndex() != null) {
                jsonGenerator.writeFieldName("expiredLogEventEndIndex")
                        .writeValue(
                                rejectedLogEventsInfo
                                        .getExpiredLogEventEndIndex());
            }

            jsonGenerator.writeEndObject();
        } catch (Throwable t) {
            throw new AmazonClientException(
                    "Unable to marshall request to JSON: " + t.getMessage(), t);
        }
    }

    private static RejectedLogEventsInfoJsonMarshaller instance;

    public static RejectedLogEventsInfoJsonMarshaller getInstance() {
        if (instance == null)
            instance = new RejectedLogEventsInfoJsonMarshaller();
        return instance;
    }

}
